==> vradi-entities-0.0.2-sources.jar: com/jurismarches/vradi/entities/QueryMakerBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntityBean;

public class QueryMakerBean extends BusinessEntityBean implements QueryMaker {

    private static final long serialVersionUID = 509784275L;

    public QueryMakerBean() {
        super();
    }

     protected PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public Set<String> QueryMaker$queries;

     public Set<String> getQueries() {
        return QueryMaker$queries;
    }

    public void addQueries(String element) {
        QueryMaker$queries.add(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void removeQueries(String element) {
        QueryMaker$queries.remove(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void clearQueries() {
        QueryMaker$queries.clear();
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }


} //QueryMakerBean

==> vradi-entities-0.0.5-sources.jar: com/jurismarches/vradi/entities/QueryMakerBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntityBean;

public class QueryMakerBean extends BusinessEntityBean implements QueryMaker {

    private static final long serialVersionUID = 1591779000L;

    public QueryMakerBean() {
        super();
    }

    protected transient PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public Set<String> QueryMaker$queries;

    public Set<String> getQueries() {
        return QueryMaker$queries;
    }

    public void addQueries(String element) {
        QueryMaker$queries.add(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void removeQueries(String element) {
        QueryMaker$queries.remove(element);
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }
    
    public void clearQueries() {
        QueryMaker$queries.clear();
        propertyChange.firePropertyChange("queries", null, QueryMaker$queries);
    }


} //QueryMakerBean
